multiformats.multiaddr
======================

.. automodule:: multiformats.multiaddr

Addr
----

.. autoclass:: multiformats.multiaddr.Addr
    :members:

Multiaddr
---------

.. autoclass:: multiformats.multiaddr.Multiaddr
    :members:

Proto
-----

.. autoclass:: multiformats.multiaddr.Proto
    :members:

byteslike
---------

.. autodata:: multiformats.multiaddr.byteslike

decode
------

.. autofunction:: multiformats.multiaddr.decode

parse
-----

.. autofunction:: multiformats.multiaddr.parse

proto
-----

.. autofunction:: multiformats.multiaddr.proto
